# Guide

A step-wise pedagogic tutorial including a quickstart. The notebooks get executed in CI for testing.

Ideally, each feature is explained in a separate clean notebook.

This makes it both easy for the user to understand the documentation, and for the developer to increase test coverage.

```{toctree}
:maxdepth: 1

quickstart
instance-metadata
database-introspection
```
